@@ -24,10 +24,13 @@ https://zh.wikipedia.org/wiki/Unicode区段
 https://liyucang-git.github.io/2019/06/17/彻底弄懂Unicode编码/
 """
 import bisect
+import os
 
 import pandas as pd
 
-WIKI_UNICODE_INFO = pd.read_pickle("jaikit/data/unicode_info.pkl")
+from jaikit.config import PACKAGE_PATH
+
+WIKI_UNICODE_INFO = pd.read_pickle(os.path.join(PACKAGE_PATH, "data/unicode_info.pkl"))
 
 breakpoints = WIKI_UNICODE_INFO["start"]
 section_indexes = list(range(-1, len(WIKI_UNICODE_INFO["start"])))
@@ -35,7 +38,9 @@ section_indexes = list(range(-1, len(WIKI_UNICODE_INFO["start"])))
 
 def character_unicode_info(character: str):
     unicode_ord: int = ord(character)
-    info = WIKI_UNICODE_INFO.iloc[section_indexes[bisect.bisect(breakpoints, unicode_ord)]]
+    info = WIKI_UNICODE_INFO.iloc[
+        section_indexes[bisect.bisect(breakpoints, unicode_ord)]
+    ]
     if pd.isna(info["平面"]):
         raise ValueError("不是Unicode字符")
     else:
